/**
 * 拍照
 */
;(function(window){
	window.localFile = {};
	
	
	
	/*
	 * 拍照
	 * @param {Function} callback 拍照成功后的回调函数
	 */
	function captureImage(callback){
		app.plusReady(function(){
			var cmr = this.camera.getCamera();
			var fmt = cmr.supportedImageFormats[0];
			var res = cmr.supportedImageResolutions[0];
			var path = '_doc/camera/';
			cmr.captureImage( function( path ){
					callback(path);
				},
				function( error ) {
					console.log( "Capture image failed: " + error.message );
				},
				{
					fileName: path,
					resolution:res,
					format:fmt
				}
			);
		})

		
	}
	
	/*
	 * 相册选择
	 * @param {Function} callback 选择照片成功后的回调函数
	 */
	function galleryImage(callback) {
		// 从相册中选择图片
		app.plusReady(function(){
			this.gallery.pick( function(path){
		    	callback(path);
		    }, function ( e ) {
		    	console.log( "取消选择图片" ,JSON.stringify(e));
		    }, {filter:"image"} );	
		})
	}
	
	/**
	 * 上传文件
	 * @param {Object} param  JSON 数据类型 {url:'服务器地址', localFileUrl: '上传文件的本地地址', postData:'其他请求参数', headers: '请求的头参数'},
	 * @param {Function} callback 
	 */
	function createUpload(param, callback) {
		 app.plusReady(function(){
			var task = this.uploader.createUpload(
				param.url,
				{ method:"POST"},
				function (response, status ) {
					try {
						response = JSON.parse(response.responseText)	
					} catch (e) {
						
					}
					
					// 上传完成
					if ( status == 200 ) { 
						
						if (response.err !== null) {
							callback(response.err);	
						} else {
							callback(response.data);
						}
						
					} else {
						app.toast('上传失败');
						callback(response);
					}
				}
			);
			
			task.addFile(param.localFileUrl, {key:"imageFile"});
			// 其他参数
			if (param.postData) {
				for (var i in param.postData) {
					task.addData(i, param.postData[i]);		
				}
			}
			
			// 自定义请求头
			if (param.headers) {
				for (var i in param.headers) {
					task.setRequestHeader(i, param.headers[i]);		
				}
			}
			task.addEventListener("statechanged", function(state){
				console.log(state);
			}, false );
			task.start(); 	
		});
		
	}
	
	/**
	 * 压缩图片
	 * @param {Object} options 图片压缩的参数
	 * @param {String} sourcesUrl 被压缩的图片地址
	 * @param {Function} callback
	 */
	function zipImage(options, sourcesUrl, callback){
		
		if (typeof options === 'string') {
			callback = sourcesUrl;
			sourcesUrl = options;
			options = {};
		}
		
		var saveZipPath = "_doc/" + Date.now() +".png";
		var zipOptions = app.extend({
    		src: sourcesUrl,
			dst: saveZipPath,
			width: "200px",
			height: "200px",
			format: "png",
			quality: 20
        },  options);
        app.plusReady(function(){
        	this.zip.compressImage(zipOptions,function() {
    			callback(saveZipPath);
    		}, function(){
    			callback(sourcesUrl);
    		});
        })
	}
	/**
	 * 图片转换成base64
	 * @param {Object} imageUrl
	 * @param {Function} callback
	 */
	function convertImageToBase64(imageUrl, callback){
		var oCanvas = document.createElement('canvas');
		oCanvas.width = 200;
		oCanvas.height = 200;
		var ctx = oCanvas.getContext('2d');
		var oImg = null;
		app.plusReady(function(){
			imageUrl = this.io.convertLocalFileSystemURL(imageUrl);
			getImage(imageUrl, getBase64)
		})
		
		function getImage(imageUrl, callback){
			oImg = document.createElement('img');
			oImg.onload = callback;
			oImg.src = imageUrl;
		}
		function getBase64(){
			ctx.drawImage(this, 0, 0);
			callback(oCanvas.toDataURL());
			oCanvas.remove();
			oCanvas = null;
			oImg = null;
		}
	}
	localFile.captureImage = captureImage;
	localFile.galleryImage = galleryImage;
	localFile.createUpload = createUpload;
	localFile.zipImage = zipImage;
	localFile.convertImageToBase64 = convertImageToBase64;
}(window))
